"use strict";
goog.provide("Blockly.Arduino.fashionstar");
goog.require("Blockly.Arduino");


/********************************************
Seeed 传感器
*********************************************/

// 传感器-超声波测距
Blockly.Arduino.Seeed_Ultrasonic = function() {
  // var pin = this.Arduino.valueToCode(this, "PIN", Blockly.Arduino.ORDER_ATOMIC);
  var dropdown_pin = Blockly.Arduino.valueToCode(this, 'PIN', Blockly.Arduino.ORDER_ATOMIC);
  // var pin = this.getFieldValue("PIN");
  Blockly.Arduino.definitions_['include_Ultrasonic'] = '#include <Seeed_Ultrasonic.h>';
  Blockly.Arduino.definitions_['var_declare_Ultrasonic'] = 'Seeed_Ultrasonic seeed_ultrasonic_' + dropdown_pin + '(' + dropdown_pin + ');';
  var code = 'seeed_ultrasonic_' + dropdown_pin + '.MeasureInCentimeters()';
  return [code, Blockly.Arduino.ORDER_ATOMIC];
}

// 传感器-PAJ7620手势识别传感器-更新数据
Blockly.Arduino.Seeed_PAJ7620_Gesture_Update = function() {
  // var code = 'Vector normAccel = mpu.readNormalizeAccel();\nVector normGyro = mpu.readNormalizeGyro();\n';
  var code = 'uint8_t data = 0;\npaj7620ReadReg(0x43, 1, &data);\n';
  return code;
 };

// 传感器-PAJ7620手势识别传感器-判断数据
Blockly.Arduino.Seeed_PAJ7620_Read_Gesture = function() {
  Blockly.Arduino.definitions_['include_Wire'] = '#include <Wire.h>';
  Blockly.Arduino.definitions_['includepaj7620'] = '#include <paj7620.h>';
  Blockly.Arduino.setups_['setup_paj7620Init'] = 'paj7620Init();';
  var PAJ7620_Gesture_TYPE = this.getFieldValue('PAJ7620_Gesture_TYPE');
  var code = PAJ7620_Gesture_TYPE;
  return [code, Blockly.Arduino.ORDER_ATOMIC];
 };

// 传感器-LSM6DS3六轴陀螺仪-获取数据
Blockly.Arduino.LSM6DS3 = function() {
  Blockly.Arduino.definitions_['includeSparkFunLSM6DS3'] = '#include <SparkFunLSM6DS3.h>';
  Blockly.Arduino.definitions_['include_Wire'] = '#include <Wire.h>';
  Blockly.Arduino.definitions_['var_declare_LSM6DS3'] = 'LSM6DS3 mpu_lsm6ds3(I2C_MODE, 0x6A);';
  Blockly.Arduino.setups_['setup_lsm6ds3'] = 'mpu_lsm6ds3.begin();';
  var LSM6DS3_TYPE = this.getFieldValue('LSM6DS3_TYPE');
  var code = LSM6DS3_TYPE;
  return [code, Blockly.Arduino.ORDER_ATOMIC];
 };


/********************************************
Seeed 8×8 RGB 点阵
*********************************************/

Blockly.Arduino.Seeed_display_Matrix_LedArray = function () {
  var color_dic = {
    "#ff0000": "0x00",
    "#ff9900": "0x12",
    "#ffff00": "0x18",
    "#33ff33": "0x52",
    "#33ffff": "0x7f",
    "#3366ff": "0xaa",
    "#6600cc": "0xc3",
    "#ff99ff": "0xdc",
    "#ffffff": "0xfe",
    "#000000": "0xff",
  };
  var varName = this.getFieldValue("VAR");
  var code = "{";
  for (var i = 1; i < 9; i++) {
    code += "\n  ";
    for (var j = 1; j < 9; j++) {
      code += color_dic[this.getFieldValue("RGB_" + i + j)];
      code += ",";
    }
  }
  code += "\n};";
  Blockly.Arduino.definitions_[varName] = "uint8_t " + varName + "[]=" + code;
  return [varName, Blockly.Arduino.ORDER_ATOMIC];
};

Blockly.Arduino.Seeed_display_Matrix_LedArray1 = function () {
  var color_dic = {
    "#ff0000": "0x00,",
    "#ff9900": "0x12,",
    "#ffff00": "0x18,",
    "#33ff33": "0x52,",
    "#33ffff": "0x7f,",
    "#3366ff": "0xaa,",
    "#6600cc": "0xc3,",
    "#ff99ff": "0xdc,",
    "#ffffff": "0xfe,",
    "#000000": "0xff,",
  };
  var colour = color_dic[this.getFieldValue("colour")];
  var varName = this.getFieldValue("VAR");
  var a = new Array();
  for (var i = 1; i < 9; i++) {
    a[i] = new Array();
    for (var j = 1; j < 9; j++) {
      a[i][9 - j] = this.getFieldValue("a" + i + j) == "TRUE" ? 1 : 0;
    }
  }
  var code = "{";
  var color_variable = "ff";
  for (var i = 8; i > 0; i--) {
    var tmp = "";
    for (var j = 8; j > 0; j--) {
      if (a[i][j] == 1) {
        color_variable = colour;
      } else color_variable = "0xff,";
      tmp += color_variable;
    }
    code += "\n  " + tmp;
  }
  code += "\n};";
  Blockly.Arduino.definitions_[varName] = "uint8_t " + varName + "[]=" + code;
  return [varName, Blockly.Arduino.ORDER_ATOMIC];
};

// 显示图像
Blockly.Arduino.Seeed_display_image = function () {
  var image = Blockly.Arduino.valueToCode(
    this,
    "image",
    Blockly.Arduino.ORDER_ATOMIC
  );
  var mode = this.getFieldValue("mode");
  var display_time = Blockly.Arduino.valueToCode(
    this,
    "display_time",
    Blockly.Arduino.ORDER_ATOMIC
  );
  Blockly.Arduino.definitions_["include_grove_two_rgb_led_matrix"] =
    "#include <grove_two_rgb_led_matrix.h>\n";
  Blockly.Arduino.definitions_["var_declare_grove_two_rgb_led_matrix"] =
    "GroveTwoRGBLedMatrixClass matrix;";
  // Blockly.Arduino.setups_['grove_two_rgb_led_matrix'] = 'Wire.begin();\n  Serial.begin(9600);\n  delay(1000);\n  uint16_t VID = 0;\n  VID = matrix.getDeviceVID();\n  if (VID != 0x2886) {\n  Serial.println("Can not detect led matrix!!!");\n  while (1);\n  }\n  Serial.println("Matrix init success!!!");\n';
  Blockly.Arduino.setups_["grove_two_rgb_led_matrix"] =
    "Wire.begin();\n  delay(1000);\n  uint16_t VID = 0;\n  VID = matrix.getDeviceVID();\n  if (VID != 0x2886) {\n    while (1);\n  }\n";
  var code =
    "matrix.displayFrames(" +
    image +
    ", " +
    display_time +
    ", " +
    mode +
    ", 1);\n";
  return code;
};

//画点
Blockly.Arduino.Seeed_draw_points = function () {
  var color_dic = {
    "#ff0000": "0x00",
    "#ff9900": "0x12",
    "#ffff00": "0x18",
    "#33ff33": "0x52",
    "#33ffff": "0x7f",
    "#3366ff": "0xaa",
    "#6600cc": "0xc3",
    "#ff99ff": "0xdc",
    "#ffffff": "0xfe",
    "#000000": "0xff",
  };
  var color = color_dic[this.getFieldValue("color")];
  var abscissa = Blockly.Arduino.valueToCode(
    this,
    "abscissa",
    Blockly.Arduino.ORDER_ATOMIC
  );
  var ordinate = Blockly.Arduino.valueToCode(
    this,
    "ordinate",
    Blockly.Arduino.ORDER_ATOMIC
  );
  var mode = this.getFieldValue("mode");
  var display_time = Blockly.Arduino.valueToCode(
    this,
    "display_time",
    Blockly.Arduino.ORDER_ATOMIC
  );
  Blockly.Arduino.definitions_["include_grove_two_rgb_led_matrix"] =
    "#include <grove_two_rgb_led_matrix.h>\n";
  Blockly.Arduino.definitions_["var_declare_Seeed_draw_points"] =
    "uint8_t Seeed_draw_points[]={\n  0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,\n  0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,\n  0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,\n  0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,\n  0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,\n  0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,\n  0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,\n  0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,\n};\n";
  Blockly.Arduino.definitions_["var_declare_grove_two_rgb_led_matrix"] =
    "GroveTwoRGBLedMatrixClass matrix;";
  // Blockly.Arduino.setups_['grove_two_rgb_led_matrix'] = 'Wire.begin();\n  Serial.begin(9600);\n  delay(1000);\n  uint16_t VID = 0;\n  VID = matrix.getDeviceVID();\n  if (VID != 0x2886) {\n  Serial.println("Can not detect led matrix!!!");\n  while (1);\n  }\n  Serial.println("Matrix init success!!!");\n';
  Blockly.Arduino.setups_["grove_two_rgb_led_matrix"] =
    "Wire.begin();\n  delay(1000);\n  uint16_t VID = 0;\n  VID = matrix.getDeviceVID();\n  if (VID != 0x2886) {\n    while (1);\n  }\n";
  var code =
    "if (" +
    ordinate +
    " == 0) {\n    Seeed_draw_points[(int)(" +
    abscissa +
    ")] = " +
    color +
    ";\n  } else {\n    Seeed_draw_points[(int)((" +
    ordinate +
    " * 8 + " +
    abscissa +
    "))] = " +
    color +
    ";\n  }\n matrix.displayFrames(Seeed_draw_points, " +
    display_time +
    ", " +
    mode +
    ", 1);\n";
  return code;
};

// 显示清屏
Blockly.Arduino.Seeed_clear_screen = function () {
  Blockly.Arduino.definitions_["include_grove_two_rgb_led_matrix"] =
    "#include <grove_two_rgb_led_matrix.h>\n";
  Blockly.Arduino.definitions_["var_declare_Seeed_draw_points"] =
    "uint8_t Seeed_draw_points[]={\n  0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,\n  0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,\n  0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,\n  0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,\n  0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,\n  0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,\n  0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,\n  0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,\n};\n";
  Blockly.Arduino.definitions_["var_declare_grove_two_rgb_led_matrix"] =
    "GroveTwoRGBLedMatrixClass matrix;";
  // Blockly.Arduino.setups_['grove_two_rgb_led_matrix'] = 'Wire.begin();\n  Serial.begin(9600);\n  delay(1000);\n  uint16_t VID = 0;\n  VID = matrix.getDeviceVID();\n  if (VID != 0x2886) {\n  Serial.println("Can not detect led matrix!!!");\n  while (1);\n  }\n  Serial.println("Matrix init success!!!");\n';
  Blockly.Arduino.setups_["grove_two_rgb_led_matrix"] =
    "Wire.begin();\n  delay(1000);\n  uint16_t VID = 0;\n  VID = matrix.getDeviceVID();\n  if (VID != 0x2886) {\n    while (1);\n  }\n";
  var code =
    "for (int i = 0; i <= 7; i = i + (1)) {\n  for (int j = 0; j <= 7; j = j + (1)) {\n    if (j == 0) {\n      Seeed_draw_points[(int)(i)] = 0xff;\n    } else {\n      Seeed_draw_points[(int)((j * 8 + i))] = 0xff;\n    }\n  }\n}\nmatrix.displayFrames(Seeed_draw_points, 1000, true, 1);\n";
  return code;
};

// 显示内置图案
Blockly.Arduino.Seeed_display_pattern = function () {
  var mode = this.getFieldValue("mode");
  var display_time = Blockly.Arduino.valueToCode(
    this,
    "display_time",
    Blockly.Arduino.ORDER_ATOMIC
  );
  var number = this.getFieldValue("number");
  Blockly.Arduino.definitions_["include_grove_two_rgb_led_matrix"] =
    "#include <grove_two_rgb_led_matrix.h>\n";
  Blockly.Arduino.definitions_["var_declare_grove_two_rgb_led_matrix"] =
    "GroveTwoRGBLedMatrixClass matrix;";
  // Blockly.Arduino.setups_['grove_two_rgb_led_matrix'] = 'Wire.begin();\n  Serial.begin(9600);\n  delay(1000);\n  uint16_t VID = 0;\n  VID = matrix.getDeviceVID();\n  if (VID != 0x2886) {\n  Serial.println("Can not detect led matrix!!!");\n  while (1);\n  }\n  Serial.println("Matrix init success!!!");\n';
  Blockly.Arduino.setups_["grove_two_rgb_led_matrix"] =
    "Wire.begin();\n  delay(1000);\n  uint16_t VID = 0;\n  VID = matrix.getDeviceVID();\n  if (VID != 0x2886) {\n    while (1);\n  }\n";
  var code =
    "matrix.displayEmoji(" +
    number +
    ", " +
    display_time +
    ", " +
    mode +
    ");\n";
  return code;
};

//显示字符串
Blockly.Arduino.Seeed_display_string = function () {
  var color_dic = {
    "#ff0000": "0x00",
    "#ff9900": "0x12",
    "#ffff00": "0x18",
    "#33ff33": "0x52",
    "#33ffff": "0x7f",
    "#3366ff": "0xaa",
    "#6600cc": "0xc3",
    "#ff99ff": "0xdc",
    "#ffffff": "0xfe",
    "#000000": "0xff",
  };
  var color = color_dic[this.getFieldValue("color")];
  var string = Blockly.Arduino.valueToCode(
    this,
    "string",
    Blockly.Arduino.ORDER_ATOMIC
  );
  var mode = this.getFieldValue("mode");
  var display_time = Blockly.Arduino.valueToCode(
    this,
    "display_time",
    Blockly.Arduino.ORDER_ATOMIC
  );
  Blockly.Arduino.definitions_["include_grove_two_rgb_led_matrix"] =
    "#include <grove_two_rgb_led_matrix.h>\n";
  Blockly.Arduino.definitions_["var_declare_string"] = "char string[80]={};";
  Blockly.Arduino.definitions_["var_declare_grove_two_rgb_led_matrix"] =
    "GroveTwoRGBLedMatrixClass matrix;";
  // Blockly.Arduino.setups_['grove_two_rgb_led_matrix'] = 'Wire.begin();\n  Serial.begin(9600);\n  delay(1000);\n  uint16_t VID = 0;\n  VID = matrix.getDeviceVID();\n  if (VID != 0x2886) {\n  Serial.println("Can not detect led matrix!!!");\n  while (1);\n  }\n  Serial.println("Matrix init success!!!");\n';
  Blockly.Arduino.setups_["grove_two_rgb_led_matrix"] =
    "Wire.begin();\n  delay(1000);\n  uint16_t VID = 0;\n  VID = matrix.getDeviceVID();\n  if (VID != 0x2886) {\n    while (1);\n  }\n";
  var code =
    "String(" +
    string +
    ").toCharArray(string, sizeof(string));\nmatrix.displayString(string, " +
    display_time +
    ", " +
    mode +
    ", " +
    color +
    ");\n";
  return code;
};

// 显示条形
Blockly.Arduino.Seeed_display_Bar = function () {
  var color_dic = {
    "#ff0000": "0x00",
    "#ff9900": "0x12",
    "#ffff00": "0x18",
    "#33ff33": "0x52",
    "#33ffff": "0x7f",
    "#3366ff": "0xaa",
    "#6600cc": "0xc3",
    "#ff99ff": "0xdc",
    "#ffffff": "0xfe",
    "#000000": "0xff",
  };
  var color = color_dic[this.getFieldValue("color")];
  var num = Blockly.Arduino.valueToCode(
    this,
    "num",
    Blockly.Arduino.ORDER_ATOMIC
  );
  var mode = this.getFieldValue("mode");
  var display_time = Blockly.Arduino.valueToCode(
    this,
    "display_time",
    Blockly.Arduino.ORDER_ATOMIC
  );
  Blockly.Arduino.definitions_["include_grove_two_rgb_led_matrix"] =
    "#include <grove_two_rgb_led_matrix.h>\n";
  Blockly.Arduino.definitions_["var_declare_grove_two_rgb_led_matrix"] =
    "GroveTwoRGBLedMatrixClass matrix;";
  // Blockly.Arduino.setups_['grove_two_rgb_led_matrix'] = 'Wire.begin();\n  Serial.begin(9600);\n  delay(1000);\n  uint16_t VID = 0;\n  VID = matrix.getDeviceVID();\n  if (VID != 0x2886) {\n  Serial.println("Can not detect led matrix!!!");\n  while (1);\n  }\n  Serial.println("Matrix init success!!!");\n';
  Blockly.Arduino.setups_["grove_two_rgb_led_matrix"] =
    "Wire.begin();\n  delay(1000);\n  uint16_t VID = 0;\n  VID = matrix.getDeviceVID();\n  if (VID != 0x2886) {\n    while (1);\n  }\n";
  var code =
    "matrix.displayBar(" +
    num +
    ", " +
    display_time +
    ", " +
    mode +
    ", " +
    color +
    ");\n";
  return code;
};

// 使用指定颜色显示波形
Blockly.Arduino.Seeed_display_waveform = function () {
  var color_dic = {
    "#ff0000": "0x00",
    "#ff9900": "0x12",
    "#ffff00": "0x18",
    "#33ff33": "0x52",
    "#33ffff": "0x7f",
    "#3366ff": "0xaa",
    "#6600cc": "0xc3",
    "#ff99ff": "0xdc",
    "#ffffff": "0xfe",
    "#000000": "0xff",
  };
  var color = color_dic[this.getFieldValue("color")];
  var mode = this.getFieldValue("mode");
  var display_time = Blockly.Arduino.valueToCode(
    this,
    "display_time",
    Blockly.Arduino.ORDER_ATOMIC
  );
  Blockly.Arduino.definitions_["include_grove_two_rgb_led_matrix"] =
    "#include <grove_two_rgb_led_matrix.h>\n";
  Blockly.Arduino.definitions_["var_declare_grove_two_rgb_led_matrix"] =
    "GroveTwoRGBLedMatrixClass matrix;";
  // Blockly.Arduino.setups_['grove_two_rgb_led_matrix'] = 'Wire.begin();\n  Serial.begin(9600);\n  delay(1000);\n  uint16_t VID = 0;\n  VID = matrix.getDeviceVID();\n  if (VID != 0x2886) {\n  Serial.println("Can not detect led matrix!!!");\n  while (1);\n  }\n  Serial.println("Matrix init success!!!");\n';
  Blockly.Arduino.setups_["grove_two_rgb_led_matrix"] =
    "Wire.begin();\n  delay(1000);\n  uint16_t VID = 0;\n  VID = matrix.getDeviceVID();\n  if (VID != 0x2886) {\n    while (1);\n  }\n";
  var code =
    "matrix.displayColorWave(" +
    color +
    ", " +
    display_time +
    ", " +
    mode +
    ");\n";
  return code;
};

// 显示内置动画
Blockly.Arduino.Seeed_show_built_in_animation = function () {
  var num = this.getFieldValue("num");
  var mode = this.getFieldValue("mode");
  var display_time = Blockly.Arduino.valueToCode(
    this,
    "display_time",
    Blockly.Arduino.ORDER_ATOMIC
  );
  Blockly.Arduino.definitions_["include_grove_two_rgb_led_matrix"] =
    "#include <grove_two_rgb_led_matrix.h>\n";
  Blockly.Arduino.definitions_["var_declare_grove_two_rgb_led_matrix"] =
    "GroveTwoRGBLedMatrixClass matrix;";
  // Blockly.Arduino.setups_['grove_two_rgb_led_matrix'] = 'Wire.begin();\n  Serial.begin(9600);\n  delay(1000);\n  uint16_t VID = 0;\n  VID = matrix.getDeviceVID();\n  if (VID != 0x2886) {\n  Serial.println("Can not detect led matrix!!!");\n  while (1);\n  }\n  Serial.println("Matrix init success!!!");\n';
  Blockly.Arduino.setups_["grove_two_rgb_led_matrix"] =
    "Wire.begin();\n  delay(1000);\n  uint16_t VID = 0;\n  VID = matrix.getDeviceVID();\n  if (VID != 0x2886) {\n    while (1);\n  }\n";
  var code =
    "matrix.displayColorAnimation(" +
    num +
    ", " +
    display_time +
    ", " +
    mode +
    ");\n";
  return code;
};

// 使用指定颜色刷屏
Blockly.Arduino.Seeed_swipe = function () {
  var color_dic = {
    "#ff0000": "0x00",
    "#ff9900": "0x12",
    "#ffff00": "0x18",
    "#33ff33": "0x52",
    "#33ffff": "0x7f",
    "#3366ff": "0xaa",
    "#6600cc": "0xc3",
    "#ff99ff": "0xdc",
    "#ffffff": "0xfe",
    "#000000": "0xff",
  };
  var color = color_dic[this.getFieldValue("color")];
  var mode = this.getFieldValue("mode");
  var display_time = Blockly.Arduino.valueToCode(
    this,
    "display_time",
    Blockly.Arduino.ORDER_ATOMIC
  );
  Blockly.Arduino.definitions_["include_grove_two_rgb_led_matrix"] =
    "#include <grove_two_rgb_led_matrix.h>\n";
  Blockly.Arduino.definitions_["var_declare_Seeed_swipe"] =
    "uint8_t Seeed_swipe[]={\n  0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,\n  0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,\n  0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,\n  0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,\n  0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,\n  0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,\n  0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,\n  0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,\n};\n";
  Blockly.Arduino.definitions_["var_declare_grove_two_rgb_led_matrix"] =
    "GroveTwoRGBLedMatrixClass matrix;";
  // Blockly.Arduino.setups_['grove_two_rgb_led_matrix'] = 'Wire.begin();\n  Serial.begin(9600);\n  delay(1000);\n  uint16_t VID = 0;\n  VID = matrix.getDeviceVID();\n  if (VID != 0x2886) {\n  Serial.println("Can not detect led matrix!!!");\n  while (1);\n  }\n  Serial.println("Matrix init success!!!");\n';
  Blockly.Arduino.setups_["grove_two_rgb_led_matrix"] =
    "Wire.begin();\n  delay(1000);\n  uint16_t VID = 0;\n  VID = matrix.getDeviceVID();\n  if (VID != 0x2886) {\n    while (1);\n  }\n";
  var code =
    "for (int i = 0; i <= 7; i = i + (1)) {\n  for (int j = 0; j <= 7; j = j + (1)) {\n    if (j == 0) {\n      Seeed_swipe[(int)(i)] = " +
    color +
    ";\n    } else {\n      Seeed_swipe[(int)((j * 8 + i))] = " +
    color +
    ";\n    }\n  }\n}\nmatrix.displayFrames(Seeed_swipe, 1000, true, 1);\n";
  return code;
};




